package models

import (
	"github.com/beego/beego/v2/client/orm"
	"github.com/rdlucklib/rdluck_tools/paging"
)

type CygxActivityVideo struct {
	VideoId       int    `orm:"column(video_id);pk"description:"视频id"`
	VideoName     string `description:"视频名称"`
	ActivityId    int    ` description:"活动ID"`
	ModifyDate    string `description:"更新时间"`
	VideoDuration string `description:"视频时长"`
	VideoCounts   int    `description:"播放量"`
	VideoUrl      string `description:"视频地址"`
	CreateTime    string `description:"创建时间"`
}

type CygxActivityVideoResp struct {
	VideoId           int    `orm:"column(video_id);pk"description:"视频id"`
	ChartPermissionId int    `description:"权限id"`
	VideoName         string `description:"视频名称"`
	ActivityId        int    ` description:"活动ID"`
	ModifyDate        string `description:"更新时间"`
	VideoDuration     string `description:"视频时长"`
	VideoCounts       int    `description:"播放量"`
	VideoUrl          string `description:"视频地址"`
	CreateTime        string `description:"创建时间"`
}

type CygxActivityVideoReq struct {
	VideoName     string `description:"视频名称"`
	VideoDuration string `description:"视频时长"`
	VideoUrl      string `description:"视频地址"`
}

//string `orm:"column(label)";description:"主题"`
//活动详情
type CygxActivityVideoListResp struct {
	ActivityId    int    `description:"活动ID 等于0新增活动，大于0修改活动"`
	Id            int    `orm:"column(video_id)";description:"视频id"`
	Title         string `orm:"column(video_name)";description:"视频名称"`
	ResourceUrl   string `orm:"column(video_url)";description:"视频地址"`
	VideoDuration string `description:"视频时长"`
}

type CygxActivityVideoListRep struct {
	Paging *paging.PagingItem `description:"分页数据"`
	List   []*CygxActivityVideoListResp
}

//列表
func GetActivityVideoListAll(condition string, pars []interface{}, startSize, pageSize int) (items []*CygxActivityVideoListResp, err error) {
	o := orm.NewOrm()
	sql := `SELECT art.*,v.video_id,v.video_name,v.video_url,video_duration FROM cygx_activity as art  INNER JOIN cygx_activity_video AS v ON v.activity_id = art.activity_id   WHERE 1= 1  `
	if condition != "" {
		sql += condition
	}
	sql += ` LIMIT ?,?`
	_, err = o.Raw(sql, pars, startSize, pageSize).QueryRows(&items)
	return
}

func UpdateActivityVideoCounts(activityId int) (err error) {
	sql := `UPDATE cygx_activity_video SET video_counts = video_counts+1 WHERE activity_id = ?  `
	o := orm.NewOrm()
	_, err = o.Raw(sql, activityId).Exec()
	return
}

// GetCygxActivityVideoByActivityId 获取活动视频
func GetCygxActivityVideoByActivityId(activityId int) (item *CygxActivityVideo, err error) {
	sql := `SELECT * FROM cygx_activity_video WHERE activity_id = ? LIMIT 1 `
	err = orm.NewOrm().Raw(sql, activityId).QueryRow(&item)
	return
}

// GetCygxActivityVideoById 获取活动视频
func GetCygxActivityVideoById(activityId int) (item *CygxActivityVideo, err error) {
	sql := `SELECT * FROM cygx_activity_video WHERE video_id = ? LIMIT 1 `
	err = orm.NewOrm().Raw(sql, activityId).QueryRow(&item)
	return
}

//列表
func GetActivityVideoList(condition string, pars []interface{}, startSize, pageSize int) (items []*CygxActivityVideoResp, err error) {
	o := orm.NewOrm()
	sql := `SELECT
	v.*,art.chart_permission_id
FROM
	cygx_activity_video AS v 
	INNER JOIN cygx_activity as art ON art.activity_id = v.activity_id    WHERE 1= 1  `
	if condition != "" {
		sql += condition
	}
	sql += ` LIMIT ?,?`
	_, err = o.Raw(sql, pars, startSize, pageSize).QueryRows(&items)
	return
}
