package models

import (
	"github.com/beego/beego/v2/client/orm"
	"time"
)

type CygxIndustrialActivityGroupManagement struct {
	Id                     int       `orm:"column(id);pk" description:"主键ID"`
	ActivityId             int       `description:"活动ID"`
	IndustrialManagementId int       `description:"cygx_industrial_management表的主键ID"`
	Source                 int       `description:"来源，1 活动，2专项调研"`
	CreateTime             time.Time `description:"创建时间"`
}

type CygxIndustrialActivityGroupSubject struct {
	Id                  int       `orm:"column(id);pk" description:"主键ID"`
	ActivityId          int       `description:"活动ID"`
	IndustrialSubjectId int       `description:"cygx_industrial_subject表的文章ID"`
	Source              int       `description:"来源，1 活动，2专项调研"`
	CreateTime          time.Time `description:"创建时间"`
}

type CygxIndustrialSubject struct {
	IndustrialSubjectId    int       `orm:"column(industrial_subject_id);pk" description:"标的id"`
	IndustrialManagementId int       `description:"产业id"`
	SubjectName            string    `description:"标的名称"`
	CreateTime             time.Time `description:"创建时间"`
	Source                 int       `description:"来源,1正常添加，2：通过文章添加，3通过活动添加(默认为1)"`
}

//获取标的列表
func GetCygxIndustrialSubjectList(subjectName string) (items []*CygxIndustrialSubject, err error) {
	o := orm.NewOrm()
	sql := `SELECT
				s.*
			FROM
				cygx_industrial_subject as s 
				INNER JOIN  cygx_industrial_management as m ON  m.industrial_management_id = s.industrial_management_id
			WHERE
				subject_name = ? `
	_, err = o.Raw(sql, subjectName).QueryRows(&items)
	return
}

// AddCygxActiuvityGroupMulti 批量添加
func AddCygxActiuvityGroupMulti(items []*CygxIndustrialActivityGroupManagement, itemsSubject []*CygxIndustrialActivityGroupSubject) (err error) {
	o, err := orm.NewOrm().Begin()
	if err != nil {
		return
	}
	defer func() {
		if err == nil {
			o.Commit()
		} else {
			o.Rollback()
		}
	}()
	if len(items) > 0 {
		//批量添加关联的产业
		_, err = o.InsertMulti(len(items), items)
	}
	if len(itemsSubject) > 0 {
		//批量添加关联的标的
		_, err = o.InsertMulti(len(itemsSubject), itemsSubject)
	}
	return
}

// GetActivityIndustryRelationList 获取活动与产业关联列表
func GetActivityIndustryRelationList(condition string, pars []interface{}) (list []*CygxIndustrialActivityGroupManagement, err error) {
	sql := `SELECT
				a.activity_id,
				b.industrial_management_id
			FROM
				cygx_activity AS a
			JOIN cygx_industrial_activity_group_management AS b ON a.activity_id = b.activity_id
			WHERE
				1 = 1 `
	if condition != `` {
		sql += condition
	}
	_, err = orm.NewOrm().Raw(sql, pars).QueryRows(&list)
	return
}