package models

import (
	"github.com/beego/beego/v2/client/orm"
	"github.com/rdlucklib/rdluck_tools/paging"
	"time"
)

type CygxResourceData struct {
	Id          int       `orm:"column(id);pk"`
	SourceId    int       `description:"资源ID"`
	Source      string    `description:"资源类型 报告 ：article 、图表 ：newchart、微路演 ：roadshow、活动 ：activity、活动视频：activityvideo、活动音频：activityvoice、专项调研活动：activityspecial"`
	Title       string    `description:"标题"`
	Annotation  string    `description:"核心观点"`
	CreateTime  time.Time `description:"创建时间"`
	PublishDate string    `description:"发布时间"`
	Abstract    string    `description:"摘要"`
}

type CygxResourceDataResp struct {
	Id              int                        `orm:"column(id);pk"`
	SourceId        int                        `description:"资源ID"`
	Source          string                     `description:"资源类型 报告 ：article 、图表 ：newchart、微路演 ：roadshow、活动 ：activity、活动视频：activityvideo、活动音频：activityvoice、专项调研活动：activityspecial"`
	PublishDate     string                     `description:"发布时间"`
	Article         *HomeArticle               `description:"文章"`
	Newchart        *HomeChartListResp         `description:"图表"`
	Roadshow        *MicroRoadShowPageList     `description:"微路演"`
	Activity        *ActivityDetail            `description:"活动"`
	Activityvideo   *MicroRoadShowPageList     `description:"活动视频"`
	Activityvoice   *MicroRoadShowPageList     `description:"活动音频"`
	Activityspecial *CygxActivitySpecialDetail `description:"专项调研活动"`
}

//Source      string    `description:"资源类型 报告 ：article 、图表 ：newchart、微路演 ：roadshow、活动 ：activity、活动视频：activityvideo、活动音频：activityvoice、专项调研活动：activityspecial"`
type HomeResourceDataListResp struct {
	Paging *paging.PagingItem
	List   []*CygxResourceDataResp `description:"列表"`
}

//列表
func GetResourceDataList(condition string, pars []interface{}, startSize, pageSize int) (items []*CygxResourceData, err error) {
	o := orm.NewOrm()
	sql := `SELECT	 *   FROM cygx_resource_data  WHERE 1= 1 `
	if condition != "" {
		sql += condition
	}
	sql += ` ORDER BY publish_date  DESC ,  id  DESC   LIMIT ?,? `
	_, err = o.Raw(sql, pars, startSize, pageSize).QueryRows(&items)
	return
}

//获取用户报名成功数量
func GetResourceDataCount(condition string, pars []interface{}) (count int, err error) {
	sqlCount := `SELECT COUNT(1) AS count FROM cygx_resource_data    WHERE 1= 1 ` + condition
	o := orm.NewOrm()
	err = o.Raw(sqlCount, pars).QueryRow(&count)
	return
}

//添加
func AddCygxResourceData(item *CygxResourceData) (lastId int64, err error) {
	o := orm.NewOrm()
	lastId, err = o.Insert(item)
	return
}

//删除数据
func DeleteResourceData(sourceId int, source string) (err error) {
	o := orm.NewOrm()
	sql := ` DELETE FROM cygx_resource_data WHERE source_id = ? AND source =?  `
	_, err = o.Raw(sql, sourceId, source).Exec()
	return
}

//修改数据
func UpdateResourceData(sourceId int, source, publishDate string) (err error) {
	o := orm.NewOrm()
	sql := `UPDATE cygx_resource_data SET publish_date=?  WHERE source_id=?  AND source =? `
	_, err = o.Raw(sql, publishDate, sourceId, source).Exec()
	return
}

//批量删除
func DeleteResourceDataList(condition string, pars []interface{}) (err error) {
	if condition == "" {
		return
	}
	o := orm.NewOrm()
	sql := `DELETE  FROM cygx_resource_data   WHERE  1=1 ` + condition
	_, err = o.Raw(sql, pars).Exec()
	return
}
