package services

import (
	"errors"
	"fmt"
	"hongze/hongze_cygx/models"
	"hongze/hongze_cygx/utils"
	"strconv"
	"strings"
	"time"
)

func GetResourceDataList(condition string, pars []interface{}, startSize, pageSize int, user *models.WxUserItem) (items []*models.CygxResourceDataResp, err error) {

	uid := user.UserId
	list, e := models.GetResourceDataList(condition, pars, startSize, pageSize)
	if e != nil {
		err = errors.New("GetResourceDataList, Err: " + e.Error())
		return
	}
	mapItems := make(map[string]*models.CygxResourceDataResp)
	for _, v := range list {
		//预处理文章
		item := new(models.CygxResourceDataResp)
		item.Id = v.Id
		item.SourceId = v.SourceId
		item.Source = v.Source
		item.PublishDate = utils.TimeRemoveHms2(v.PublishDate)
		mapItems[fmt.Sprint(v.Source, v.SourceId)] = item
	}

	var articleIds []int
	var newchartIds []int
	var roadshowIds []string
	var activityIds []int
	var activityvideoIds []string
	var activityvoiceIds []string
	var activityspecialIds []int
	//Source      string    `description:"资源类型 报告 ：article 、图表 ：newchart、微路演 ：roadshow、活动 ：activity、活动视频：activityvideo、活动音频：activityvoice、专项调研活动：activityspecial"`
	for _, v := range list {
		if v.Source == "article" {
			articleIds = append(articleIds, v.SourceId)
		} else if v.Source == "newchart" {
			newchartIds = append(newchartIds, v.SourceId)
		} else if v.Source == "roadshow" {
			roadshowIds = append(roadshowIds, strconv.Itoa(v.SourceId))
		} else if v.Source == "activity" {
			activityIds = append(activityIds, v.SourceId)
		} else if v.Source == "activityvideo" {
			activityvideoIds = append(activityvideoIds, strconv.Itoa(v.SourceId))
		} else if v.Source == "activityvoice" {
			activityvoiceIds = append(activityvoiceIds, strconv.Itoa(v.SourceId))
		} else if v.Source == "activityspecial" {
			activityspecialIds = append(activityspecialIds, v.SourceId)
		}
	}

	//处理文章
	if len(articleIds) > 0 {
		pars = make([]interface{}, 0)
		condition = ` AND a.article_id IN (` + utils.GetOrmInReplace(len(articleIds)) + `)`
		pars = append(pars, articleIds)

		listArticle, e := models.GetHomeList(condition, pars, 0, len(articleIds))
		if e != nil {
			err = errors.New("GetResourceDataList, Err: " + e.Error())
			return
		}

		listArticle, e = HandleArticleCategoryImg(listArticle)
		if e != nil {
			err = errors.New("HandleArticleCategoryImg, Err: " + e.Error())
			return
		}
		for _, v := range listArticle {
			v.Body = ""
			mapItems[fmt.Sprint("article", v.ArticleId)].Article = v
		}
	}

	detail, e := models.GetConfigByCode("city_img_url")
	if e != nil {
		err = errors.New("GetResourceDataList, Err: " + e.Error())
		return
	}
	detailChart, e := models.GetConfigByCode("chart_img_url")
	if e != nil {
		err = errors.New("GetResourceDataList, Err: " + e.Error())
		return
	}
	addressList := strings.Split(detail.ConfigValue, "{|}")
	mapAddress := make(map[string]string)
	chartList := strings.Split(detailChart.ConfigValue, "{|}")
	mapChart := make(map[string]string)
	var cityName string
	var chartName string
	var imgUrl string
	var imgUrlChart string
	for _, v := range addressList {
		vslice := strings.Split(v, "_")
		cityName = vslice[0]
		imgUrl = vslice[len(vslice)-1]
		mapAddress[cityName] = imgUrl
	}
	for _, v := range chartList {
		vslice := strings.Split(v, "_")
		chartName = vslice[0]
		imgUrlChart = vslice[len(vslice)-1]
		mapChart[chartName] = imgUrlChart
	}
	var imgUrlResp string

	//处理活动
	if len(activityIds) > 0 {
		for _, vss := range activityIds {
			imgUrlResp += strconv.Itoa(vss) + ","
		}
		pars = make([]interface{}, 0)
		condition = ` AND art.activity_id IN (` + utils.GetOrmInReplace(len(activityIds)) + `)`
		pars = append(pars, activityIds)
		activityList, e := models.GetActivityListNew(condition, pars, uid, 0, len(activityIds), 0, 0, "")
		if e != nil {
			err = errors.New("GetResourceDataList, Err: " + e.Error())
			return
		}
		//处理不同的报名方式按钮回显
		mapActivitySignup, e := GetActivitySignupResp(activityIds, user)
		if e != nil {
			e = errors.New("GetActivitySignupResp, Err: " + e.Error())
			return
		}

		var activityListRersp []*models.ActivityDetail
		for _, v := range activityList {
			v.SignupType = mapActivitySignup[v.ActivityId]
			activityListRersp = append(activityListRersp, ActivityButtonShow(v))
		}
		for _, v := range activityListRersp {
			if v == nil {
				continue
			}
			if v.ActivityType == 0 {
				if mapAddress[v.City] != "" {
					imgUrlResp = mapAddress[v.City]
				} else {
					imgUrlResp = mapAddress["其它"]
				}
			} else {
				if mapChart[v.ChartPermissionName] != "" {
					imgUrlResp = mapChart[v.ChartPermissionName]
				}
			}
			v.SourceType = 1
			mapItems[fmt.Sprint("activity", v.ActivityId)].Activity = v
		}
	}

	//处理图表
	if len(newchartIds) > 0 {
		pars = make([]interface{}, 0)
		condition = ` AND a.chart_id IN (` + utils.GetOrmInReplace(len(newchartIds)) + `)`
		pars = append(pars, newchartIds)
		chartDateList, e := models.GetChartListCollectionNew(condition, pars, uid, 0, len(newchartIds))
		if e != nil {
			err = errors.New("GetResourceDataList, Err: " + e.Error())
			return
		}
		for _, v := range chartDateList {
			mapItems[fmt.Sprint("newchart", v.ChartId)].Newchart = v
		}
	}

	//处理专项调研
	if len(activityspecialIds) > 0 {
		pars = make([]interface{}, 0)
		condition = ` AND art.activity_id IN (` + utils.GetOrmInReplace(len(activityspecialIds)) + `)`
		pars = append(pars, activityspecialIds)
		activitySpeciallist, e := models.GetCygxActivitySpecialDetailList(condition, pars, user.UserId, 0, len(activityspecialIds))
		if e != nil {
			err = errors.New("GetCygxActivitySpecialDetailList, Err: " + e.Error())
			return
		}
		UserMap, e := GetSpecialTripUserMap(activityIds, user.UserId)
		if e != nil {
			err = errors.New("GetSpecialTripUserMap, Err: " + e.Error())
			return
		}
		for _, v := range activitySpeciallist {
			if mapChart[v.ChartPermissionName] != "" {
				imgUrlResp = mapChart[v.ChartPermissionName]
			}
			if _, ok := UserMap[v.ActivityId]; ok {
				v.IsTrip = 1
			}
			if v.Days == 0 {
				v.TripStatus = 1
				v.TripImgLink = v.TripImgLink
			} else {
				v.TripStatus = 2
				v.TripImgLink = v.TripImgLinkFix
				v.ActivityTimeText = v.ActivityTimeTextByDay
			}
			resultTimeStart := utils.StrTimeToTime(v.ActivityTime)  //时间字符串格式转时间格式
			resultTimeEnd := utils.StrTimeToTime(v.ActivityTimeEnd) //时间字符串格式转时间格式
			if resultTimeStart.After(time.Now()) {
				v.ActiveState = 1
			} else if time.Now().After(resultTimeEnd) {
				v.ActiveState = 3
			} else {
				v.ActiveState = 2
			}
			v.ImgUrl = imgUrlResp
			mapItems[fmt.Sprint("activityspecial", v.ActivityId)].Activityspecial = v

		}
	}

	if len(roadshowIds)+len(activityvideoIds)+len(activityvoiceIds) > 0 {

		audioIdstr := strings.Join(activityvoiceIds, ",")
		ideoIdsStr := strings.Join(roadshowIds, ",")
		activityVideoIdsStr := strings.Join(activityvideoIds, ",")

		list, _, e := GetMicroRoadShowMycollect(len(roadshowIds)+len(activityvideoIds)+len(activityvoiceIds), 0, audioIdstr, ideoIdsStr, activityVideoIdsStr)
		if e != nil {
			err = errors.New("GetMicroRoadShowMycollect, Err: " + e.Error())
			return
		}

		for _, item := range list {
			if item.Type == 1 {
				//音频
				count, e := models.GetVoiceCollectCount(user.UserId, item.Id)
				if e != nil {
					err = errors.New("GetVoiceCollectCount, Err: " + e.Error())
					return
				}
				if count > 0 {
					item.IsCollect = true
				}
			} else if item.Type == 2 {
				//活动视频
				count, e := models.GetActivityVideoCollectCount(user.UserId, item.Id)
				if e != nil {
					err = errors.New("GetActivityVideoCollectCount, Err: " + e.Error())
					return
				}
				if count > 0 {
					item.IsCollect = true
				}
			} else if item.Type == 3 {
				//微路演视频
				count, e := models.GetVideoCollectCount(user.UserId, item.Id)
				if e != nil {
					err = errors.New("GetVideoCollectCount, Err: " + e.Error())
					return
				}
				if count > 0 {
					item.IsCollect = true
				}
			}
		}
		// 用户权限
		authInfo, permissionArr, e := GetUserRaiPermissionInfo(user.UserId, user.CompanyId)
		if e != nil {
			err = errors.New("GetUserRaiPermissionInfo, Err: " + e.Error())
			return
		}

		// 获取默认图配置
		audioMap, videoMap, audioShareMap, videoShareMap, e := GetMicroRoadShowDefaultImgConfig()
		if e != nil {
			err = errors.New("GetMicroRoadShowDefaultImgConfig, Err: " + e.Error())
			return
		}
		//Source      string    `description:"资源类型 报告 ：article 、图表 ：newchart、微路演 ：roadshow、活动 ：activity、活动视频：activityvideo、活动音频：activityvoice、专项调研活动：activityspecial"`
		for i := range list {
			// 权限
			au := new(models.UserPermissionAuthInfo)
			au.SellerName = authInfo.SellerName
			au.SellerMobile = authInfo.SellerMobile
			au.HasPermission = authInfo.HasPermission
			au.OperationMode = authInfo.OperationMode
			if au.HasPermission == 1 {
				// 非宏观权限进一步判断是否有权限
				if list[i].ChartPermissionId != utils.HONG_GUAN_ID && !utils.InArrayByStr(permissionArr, list[i].ChartPermissionName) {
					au.HasPermission = 2
				}
			}
			// 无权限的弹框提示
			if au.HasPermission != 1 {
				if au.OperationMode == UserPermissionOperationModeCall {
					if list[i].Type == 1 {
						au.PopupMsg = UserPermissionPopupMsgCallActivity
					} else {
						au.PopupMsg = UserPermissionPopupMsgCallMicroVideo
					}
				} else {
					if list[i].Type == 1 {
						au.PopupMsg = UserPermissionPopupMsgApplyActivity
					} else {
						au.PopupMsg = UserPermissionPopupMsgApplyMicroVideo
					}
				}
			}
			list[i].AuthInfo = au
			list[i].PublishTime = utils.StrTimeToTime(list[i].PublishTime).Format(utils.FormatDate)
			// 默认图
			if list[i].BackgroundImg == "" {
				if list[i].Type == 1 {
					list[i].BackgroundImg = audioMap[list[i].ChartPermissionId]
				} else {
					list[i].BackgroundImg = videoMap[list[i].ChartPermissionId]
				}
			}
			// 分享图
			if list[i].ShareImg == "" {
				if list[i].Type == 1 {
					list[i].ShareImg = audioShareMap[list[i].ChartPermissionId]
				} else {
					list[i].ShareImg = videoShareMap[list[i].ChartPermissionId]
				}
			}
		}
		//Type                int    `description:"类型: 1-音频; 2-活动视频； 3-产业视频"`
		for _, item := range list {
			if item.Type == 1 {
				mapItems[fmt.Sprint("activityvoice", item.Id)].Activityvoice = item
			} else if item.Type == 2 {
				mapItems[fmt.Sprint("activityvideo", item.Id)].Activityvideo = item
			} else if item.Type == 3 {
				mapItems[fmt.Sprint("roadshow", item.Id)].Roadshow = item
			}
		}
	}

	for _, vList := range list {
		for _, v := range mapItems {
			if v.SourceId == vList.SourceId {
				items = append(items, v)
			}
		}
	}
	return
}

// 同步活动到最新数据表
func UpdateResourceData(sourceId int, source, doType, publishDate string) (err error) {
	defer func() {
		if err != nil {
			go utils.SendAlarmMsg("同步到最新数据表失败，Err："+err.Error()+"资源ID"+strconv.Itoa(sourceId)+"资源类型"+source+"操作方式"+doType, 3)
		}
	}()
	if doType == "add" {
		item := new(models.CygxResourceData)
		item.SourceId = sourceId
		item.Source = source
		item.PublishDate = publishDate
		item.CreateTime = time.Now()
		_, err = models.AddCygxResourceData(item)
	} else if doType == "delete" {
		err = models.DeleteResourceData(sourceId, source)
	} else if doType == "update" {
		err = models.UpdateResourceData(sourceId, source, publishDate)
	}
	return
}

// 批量删除最新图表数据
func Deletenewchart(chartIdsDelete []int) (err error) {
	defer func() {
		if err != nil {
			fmt.Println(err)
			go utils.SendAlarmMsg("批量删除最新图表数据，Err："+err.Error(), 3)
		}
	}()
	lenchartIdsDelete := len(chartIdsDelete)
	if lenchartIdsDelete == 0 {
		return
	}
	var condition string
	var pars []interface{}
	condition += ` AND source = 'newchart' AND source_id IN (` + utils.GetOrmInReplace(lenchartIdsDelete) + `) `
	pars = append(pars, chartIdsDelete)
	err = models.DeleteResourceDataList(condition, pars)
	return
}
